@@ -22,7 +22,11 @@ import pandas as pd
 
 
 from jgtutils import jgtconstants as c
+from jgtutils.coltypehelper import DTYPE_DEFINITIONS
 
+from jgtutils.jgtconstants import NB_BARS_BY_DEFAULT_IN_CDS
+
+#DTYPE_COLTYPE = coltypehelper.get_dtype_definitions()
 
 # %%
 def createFromPDSFileToCDSFile(
@@ -43,7 +47,8 @@ def createFromPDSFileToCDSFile(
     talligator_flag=False,
     talligator_period_jaws=377,
     viewpath=False,
-    quotescount=300,
+    quotescount=NB_BARS_BY_DEFAULT_IN_CDS,
+    dropna_volume=True,
 ):
     """
     Create a CDS file from a PDS file.
@@ -94,6 +99,7 @@ def createFromPDSFileToCDSFile(
         return cdspath,None
     # Working around an issue with keep_bid_ask, we use the value supplied in this function to override the value in the request
     rq.keep_bid_ask = keep_bid_ask
+    rq.dropna_volume = dropna_volume
 
     cdf = createFromPDSFile(
         instrument, timeframe, quiet,         
@@ -134,7 +140,7 @@ def readCDSFile(
     # Define the file path based on the environment variable or local path
     data_path_cds = get_data_path("cds", use_full=use_full)
     fpath = pds.mk_fullpath(instrument, timeframe, "csv", data_path_cds)
-    cdf = pd.read_csv(fpath)
+    cdf = pd.read_csv(fpath,dtype=DTYPE_DEFINITIONS)
 
     # Set 'Date' as the index and convert it to datetime
     cdf["Date"] = pd.to_datetime(cdf["Date"])
@@ -190,7 +196,15 @@ def createFromPDSFile(
             
         return None
 
+def __rq_patch(instrument,timeframe,rq):
+    if rq is None:
+        rq = JGTCDSRequest()
+        rq.instrument=instrument
+        rq.timeframe=timeframe
+    return rq
+
 def _getPH_to_DF_wrapper_240304(instrument, timeframe, quiet, cc, use_full, rq,use_fresh=False ,run_jgtfxcli_on_error=True,columns_to_remove=None):
+    rq=__rq_patch(instrument,timeframe,rq)
     #print("_getPH_to_DF_wrapper_240304 rq.quotescount:",rq.quotescount)
     df=pds.getPH(instrument,
             timeframe,
@@ -200,6 +214,7 @@ def _getPH_to_DF_wrapper_240304(instrument, timeframe, quiet, cc, use_full, rq,u
             use_fresh=use_fresh,
             run_jgtfxcli_on_error=run_jgtfxcli_on_error,
             keep_bid_ask=rq.keep_bid_ask,
+            dropna_volume=rq.dropna_volume,
             )
 
     if not quiet:
@@ -342,7 +357,7 @@ def create_and_clean_data_from_file_df(instrument:str, timeframe:str):
     return cdf
 
 
-def _save_cds_data_to_file(df, instrument:str, timeframe:str):
+def _save_cds_data_to_file(df:pd.DataFrame, instrument:str, timeframe:str):
     # Define the file path based on the environment variable or local path
     data_path = get_data_path()
     fpath = pds.mk_fullpath(instrument, timeframe, "csv", data_path)
@@ -352,7 +367,7 @@ def _save_cds_data_to_file(df, instrument:str, timeframe:str):
     return fpath
 
 
-def writeCDS(instrument, timeframe, use_full, cdf):
+def writeCDS(instrument, timeframe, use_full, cdf:pd.DataFrame):
     data_path_cds = get_data_path("cds", use_full=use_full)
     fpath = mk_fullpath(instrument, timeframe, "csv", data_path_cds)
     # print(fpath)
