@@ -541,7 +541,7 @@ def get_ph_to_df_and_create_ids_df(
         quiet=quiet,
         quote_count=rq.quotescount,
         keep_bid_ask=rq.keep_bid_ask,
-        talligator_flag=rq.talligator_flag,
+        dropna_volume=rq.dropna_volume,
     )
 
     if not quiet:
@@ -695,6 +695,37 @@ def write_ids(instrument, timeframe, use_full, cdf):
     cdf.to_csv(fpath, index=True)
     return fpath
 
+from jgtutils.coltypehelper import DTYPE_DEFINITIONS
+
+def read_ids(instrument, timeframe, use_full=False):
+    data_path_ids = get_data_path("ids", use_full=use_full)
+    fpath = pds.mk_fullpath(instrument, timeframe, "csv", data_path_ids)
+    if not os.path.exists(fpath):
+        rq: JGTIDSRequest = JGTIDSRequest()
+        rq.instrument = instrument
+        rq.timeframe = timeframe
+        rq.use_full = use_full
+        createIDSService(rq)
+    cdf = pd.read_csv(fpath, index_col=0,parse_dates=True,dtype=DTYPE_DEFINITIONS)
+    return cdf
+
+def select_value_in_currentbar(instrument, timeframe,coln, use_full=False):
+    current_bar_data = read_ids_currentbar(instrument, timeframe, use_full)
+    return current_bar_data[coln]
+
+def select_value_in_lastcompletedbar(instrument, timeframe,coln, use_full=False):
+    completed_bar = read_ids_lastcompletedbar(instrument, timeframe, use_full)
+    return completed_bar[coln]
+
+def read_ids_currentbar(instrument, timeframe, use_full):
+    df=read_ids(instrument, timeframe, use_full)
+    current_bar=df.iloc[-1]
+    return current_bar
+
+def read_ids_lastcompletedbar(instrument, timeframe, use_full):
+    df=read_ids(instrument, timeframe, use_full)
+    lastcompleted_bar=df.iloc[-2]
+    return lastcompleted_bar
 
 def createIDSService(
     rq: JGTIDSRequest = None,
@@ -707,7 +738,7 @@ def createIDSService(
     col2remove = constants.columns_to_remove
     config = jgtcommon.readconfig()
     if "columns_to_remove" in config:  # read it from config otherwise
-        col2remove = config["columns_to_remove"]
+        col2remove = config["columns_to_remove"] #@STCIssue Should be using settings (jgtutils) or what would be supplied in the request.
     quietting = True
     if verbose_level > 1:
         quietting = False
@@ -720,16 +751,17 @@ def createIDSService(
         # cdspath, cdf = cds.createFromPDSFileToCDSFile(
         # @a Migrate to IDS Logics
         # cdspath, cdf = cds.createFromPDSFileToCDSFile(
-        cdspath, cdf = create_from_pds_file_to_ids_file(
+        idspath, idf = create_from_pds_file_to_ids_file(
             rq=rq,
             quiet=quietting,
             columns_to_remove=col2remove,
             keep_bid_ask=rq.keep_bid_ask,
         )  # @STCIssue: This is not supporting -c NB_BARS_TO_PROCESS, should it ?
 
-        print_quiet(quiet, cdspath)
-        print_quiet(quiet, cdf)
-        return cdspath, cdf
+        print_quiet(quiet, idspath)
+        if verbose_level >1:
+            print_quiet(quiet, idf)
+        return idspath, idf
     except Exception as e:
         print("Failed to create IDS for : " + rq.instrument + "_" + rq.timeframe)
         print("jgtapycli::Exception in ...(: " + str(e))
